const char * serverMessages[] = {
QT_TRANSLATE_NOOP("server", "Less than two clans!"),
QT_TRANSLATE_NOOP("server", "Empty config entry"),
QT_TRANSLATE_NOOP("server", "Restricted"),
QT_TRANSLATE_NOOP("server", "Not room master"),
QT_TRANSLATE_NOOP("server", "Corrupted hedgehogs info"),
QT_TRANSLATE_NOOP("server", "too many teams"),
QT_TRANSLATE_NOOP("server", "too many hedgehogs"),
QT_TRANSLATE_NOOP("server", "There's already a team with same name in the list"),
QT_TRANSLATE_NOOP("server", "round in progress"),
QT_TRANSLATE_NOOP("server", "restricted"),
QT_TRANSLATE_NOOP("server", "REMOVE_TEAM: no such team"),
QT_TRANSLATE_NOOP("server", "Not team owner!"),
QT_TRANSLATE_NOOP("server", "Illegal room name"),
QT_TRANSLATE_NOOP("server", "Room with such name already exists"),
QT_TRANSLATE_NOOP("server", "/maxteams: specify number from 2 to 8"),
QT_TRANSLATE_NOOP("server", "Available callvote commands: kick <nickname>, map <name>, pause, newseed, hedgehogs"),
QT_TRANSLATE_NOOP("server", "callvote kick: specify nickname"),
QT_TRANSLATE_NOOP("server", "callvote kick: no such user"),
QT_TRANSLATE_NOOP("server", "callvote map: no such map"),
QT_TRANSLATE_NOOP("server", "callvote pause: no game in progress"),
QT_TRANSLATE_NOOP("server", "callvote hedgehogs: specify number from 1 to 8"),
QT_TRANSLATE_NOOP("server", "Warning! Chat flood protection activated"),
QT_TRANSLATE_NOOP("server", "Excess flood"),
QT_TRANSLATE_NOOP("server", "Game messages flood detected - 1"),
QT_TRANSLATE_NOOP("server", "Game messages flood detected - 2"),
QT_TRANSLATE_NOOP("server", "Warning! Joins flood protection activated"),
QT_TRANSLATE_NOOP("server", "There's no voting going on"),
QT_TRANSLATE_NOOP("server", "You already have voted"),
QT_TRANSLATE_NOOP("server", "Your vote counted"),
QT_TRANSLATE_NOOP("server", "Voting closed"),
QT_TRANSLATE_NOOP("server", "Pause toggled"),
QT_TRANSLATE_NOOP("server", "New voting started"),
QT_TRANSLATE_NOOP("server", "Voting expired"),
QT_TRANSLATE_NOOP("server", "kick"),
QT_TRANSLATE_NOOP("server", "map"),
QT_TRANSLATE_NOOP("server", "pause"),
QT_TRANSLATE_NOOP("server", "new seed"),
QT_TRANSLATE_NOOP("server", "number of hedgehogs in team"),
QT_TRANSLATE_NOOP("server", "Nickname is already in use"),
QT_TRANSLATE_NOOP("server", "No checker rights"),
QT_TRANSLATE_NOOP("server", "Authentication failed"),
QT_TRANSLATE_NOOP("server", "60 seconds cooldown after kick"),
QT_TRANSLATE_NOOP("server", "kicked"),
QT_TRANSLATE_NOOP("server", "Reconnected too fast"),
QT_TRANSLATE_NOOP("server", "Ping timeout"),
QT_TRANSLATE_NOOP("server", "No such room"),
QT_TRANSLATE_NOOP("server", "Room version incompatible to your hedgewars version"),
QT_TRANSLATE_NOOP("server", "Joining restricted"),
QT_TRANSLATE_NOOP("server", "Registered users only"),
QT_TRANSLATE_NOOP("server", "You are banned in this room"),
QT_TRANSLATE_NOOP("server", "Nickname already chosen"),
QT_TRANSLATE_NOOP("server", "Illegal nickname"),
QT_TRANSLATE_NOOP("server", "Protocol already known"),
QT_TRANSLATE_NOOP("server", "Bad number"),
QT_TRANSLATE_NOOP("server", "bye")
};
